==> flutter_paudio-0.0.4.tar.gz: ios/Classes/FlutterPaudioPlugin.m <==
#import "FlutterPaudioPlugin.h"
#import <AVFoundation/AVFoundation.h>

@interface FlutterPaudioPlugin ()
@property(nonatomic, strong) AVAudioPlayer *player;
@end

@implementation FlutterPaudioPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter_paudio"
            binaryMessenger:[registrar messenger]];
  FlutterPaudioPlugin* instance = [[FlutterPaudioPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"playAudio" isEqualToString:call.method]) {
    FlutterStandardTypedData *typedData = call.arguments[@"data"];
    double speed = [(NSString *) call.arguments[@"speed"] doubleValue];
    NSData *data =typedData.data;
    NSLog(@"%lu", data.length);
    NSLog(@"playAudio");
    double duration = [self playAudio: data speed: speed];
    result(@(duration));
  } else if ([@"stopAudio" isEqualToString:call.method]) {
    [self.player stop];
    result(@"success");
  } else {
    result(FlutterMethodNotImplemented);
  }
}

-(double)playAudio:(NSData *)data speed: (double)speed{   
  AVAudioPlayer *player = [[AVAudioPlayer alloc] initWithData:data error:nil];
  self.player = player;
  [player prepareToPlay];
  self.player.rate = speed;
  self.player.enableRate = true;
  [player play];
  
  
  double duration = player.duration;
  duration /= speed;
  // AVAudioFormat* format = player.format;
  // duration = duration*(25600/format.sampleRate);
  return duration;
}

-(void)stopAudio{
  [self.player stop];
}

@end

==> flutter_paudio-0.0.5.tar.gz: ios/Classes/FlutterPaudioPlugin.m <==
#import "FlutterPaudioPlugin.h"
#import <AVFoundation/AVFoundation.h>

@interface FlutterPaudioPlugin ()
@property(nonatomic, strong) AVAudioPlayer *player;
@end

@implementation FlutterPaudioPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter_paudio"
            binaryMessenger:[registrar messenger]];
  FlutterPaudioPlugin* instance = [[FlutterPaudioPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"playAudio" isEqualToString:call.method]) {
    FlutterStandardTypedData *typedData = call.arguments[@"data"];
    double speed = [(NSString *) call.arguments[@"speed"] doubleValue];
    NSData *data =typedData.data;
    NSLog(@"%lu", data.length);
    NSLog(@"playAudio");
    double duration = [self playAudio: data speed: speed];
    result(@(duration));
  } else if ([@"stopAudio" isEqualToString:call.method]) {
    [self.player stop];
    result(@"success");
  } else {
    result(FlutterMethodNotImplemented);
  }
}

-(double)playAudio:(NSData *)data speed: (double)speed{   
  AVAudioPlayer *player = [[AVAudioPlayer alloc] initWithData:data error:nil];
  self.player = player;
  [player prepareToPlay];
  self.player.rate = 1.0/speed;
  self.player.enableRate = true;
  [player play];
  
  
  double duration = player.duration;
  duration *= speed;
  // AVAudioFormat* format = player.format;
  // duration = duration*(25600/format.sampleRate);
  return duration;
}

-(void)stopAudio{
  [self.player stop];
}

@end
